@@ -1074,9 +1074,9 @@ class WordToken(caching.base.CachingMixin,models.Model):
         if form['nd']:
             if 'C' in form['lexical_scale'] and 'CelexNeighDen' not in outline:
                 try:
-                    outline['CelexNeighDen','CelexFWND'] = celex_info['ND'],celex_info['FWND']
+                    outline['CelexNeighDen'],outline['CelexFWND'] = celex_info['ND'],celex_info['FWND']
                 except KeyError:
-                    outline['CelexNeighDen','CelexFWND'] = 'NA','NA'
+                    outline['CelexNeighDen'],outline['CelexFWND'] = 'NA','NA'
             if 'W' in form['lexical_scale'] and 'BuckeyeNeighDen' not in outline:
                 outline['BuckeyeNeighDen'],outline['BuckeyeFWND'] = self.WordType.getNDs()
             if 'S' in form['lexical_scale'] and 'SpeakerNeighDen' not in outline:
@@ -1091,9 +1091,9 @@ class WordToken(caching.base.CachingMixin,models.Model):
         if form['phonotactic']:
             if 'C' in form['lexical_scale'] and 'CelexSPhoneProb' not in outline:
                 try:
-                    outline['CelexSPhoneProb','CelexBiPhoneProb'] = celex_info['SP'],celex_info['BP']
+                    outline['CelexSPhoneProb'],outline['CelexBiPhoneProb'] = celex_info['SP'],celex_info['BP']
                 except KeyError:
-                    outline['CelexSPhoneProb','CelexBiPhoneProb'] = 'NA','NA'
+                    outline['CelexSPhoneProb'],outline['CelexBiPhoneProb'] = 'NA','NA'
             if 'W' in form['lexical_scale'] and 'BuckeyeSPhoneProb' not in outline:
                 outline['BuckeyeSPhoneProb'],outline['BuckeyeBiPhoneProb'] = self.WordType.getPhonoProb()
             if 'S' in form['lexical_scale'] and 'SpeakerSPhoneProb' not in outline:
